<?php
namespace plugins\surveys\controllers;

use plugins\surveys\services\ReplyToSurvey;
/**
 * Survey controller
 * @author Jérôme Brilland
 * @version 1.0
 * @copyright (c) 2022, Jérôme Brilland
 * @license http://www.gnu.org/licenses/gpl.txt GNU General Public License
 */
class SurveyResponsesController extends \ActionController {
    
    public function doCreate() {
        $eventMediator = \IoC::resolve( 'eventmediator' );
        $i18n = \IoC::resolve( 'i18n' );
        
        $eventMediator->attach( 'invalid_survey', function() {
            $this->forward( 'controllers\ErrorController', '404' );
        } );
        $eventMediator->attach( 'survey_closed', function() use ( $i18n ) {
            $this->flash['warning'] = $i18n->__( 'surveys.survey_closed' );
            $this->forward( 'plugins\surveys\controllers\SurveyController', 'show' );
        } );
        $eventMediator->attach( 'survey_response_errors', function( $errors ) {
            \Registry::set( 'errors', $errors );
            $this->forward( 'plugins\surveys\controllers\SurveyController', 'show' );
        } );
        $eventMediator->attach( 'already_answered', function() use ( $i18n ) {
            $this->flash['warning'] = $i18n->__( 'surveys.already_taken' );
            $this->forward( 'plugins\surveys\controllers\SurveyController', 'show' );
        } );
        $eventMediator->attach( 'answers_saved', function( $result ) use ( $i18n ) {
            $this->flash['success'] = $i18n->__( 'surveys.thankyou' );
            $this->redirect( BASE_URL . 'surveys/survey/show/' . $this->request->getAttribute( 'id' ) );
        } );
        
        $replyToSurvey = new ReplyToSurvey( $this->request->getAttribute( 'id' ), $this->request->getParameter( 'answers' ) );
        $surveyResponse = $replyToSurvey->perform();
    }
}
